@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import json
 import os
 from functools import partial
@@ -13,39 +15,11 @@ from quaterion_models.heads.encoder_head import EncoderHead
 from quaterion_models.utils.classes import save_class_import, restore_class
 from quaterion_models.utils.tensors import move_to_device
 
+
 DEFAULT_ENCODER_KEY = "default"
 
 
 class MetricModel(nn.Module):
-    @classmethod
-    def collate_fn(
-        cls, batch: List[dict], encoders_collate_fns: Dict[str, CollateFnType]
-    ) -> TensorInterchange:
-        """
-        Construct batches for all encoders
-
-        :param batch:
-        :param encoders_collate_fns: Dict (or single) of collate functions associated with encoders
-        :return:
-        """
-        result = dict(
-            (key, collate_fn(batch)) for key, collate_fn in encoders_collate_fns.items()
-        )
-        return result
-
-    @classmethod
-    def get_encoders_output_size(cls, encoders: Union[Encoder, Dict[str, Encoder]]):
-        """
-        Calculate total output size of given encoders
-        :param encoders:
-        :return:
-        """
-        encoders = encoders.values() if isinstance(encoders, dict) else [encoders]
-        total_size = 0
-        for encoder in encoders:
-            total_size += encoder.embedding_size()
-        return total_size
-
     def __init__(self, encoders: Union[Encoder, Dict[str, Encoder]], head: EncoderHead):
         super(MetricModel, self).__init__()
 
@@ -60,14 +34,44 @@ class MetricModel(nn.Module):
 
         self.head = head
 
+    @classmethod
+    def collate_fn(
+        cls, batch: List[dict], encoders_collate_fns: Dict[str, CollateFnType]
+    ) -> TensorInterchange:
+        """Construct batches for all encoders
+
+        Args:
+            batch:
+            encoders_collate_fns: Dict (or single) of collate functions associated with encoders
+
+        """
+        result = dict(
+            (key, collate_fn(batch)) for key, collate_fn in encoders_collate_fns.items()
+        )
+        return result
+
+    @classmethod
+    def get_encoders_output_size(cls, encoders: Union[Encoder, Dict[str, Encoder]]):
+        """Calculate total output size of given encoders
+
+        Args:
+            encoders:
+
+        """
+        encoders = encoders.values() if isinstance(encoders, dict) else [encoders]
+        total_size = 0
+        for encoder in encoders:
+            total_size += encoder.embedding_size
+        return total_size
+
     def train(self, mode: bool = True):
         super(MetricModel, self).train(mode)
 
     def get_collate_fn(self) -> Callable:
-        """
-        Construct a function to convert input data into neural network inputs
+        """Construct a function to convert input data into neural network inputs
 
-        :return: neural network inputs
+        Returns:
+            neural network inputs
         """
         return partial(
             MetricModel.collate_fn,
@@ -84,14 +88,15 @@ class MetricModel(nn.Module):
     def encode(
         self, inputs: Union[List[Any], Any], batch_size=32, to_numpy=True
     ) -> Union[torch.Tensor, np.ndarray]:
+        """Encode data in batches
 
-        """
-        Encode data in batches
+        Args:
+            inputs: list of input data to encode
+            batch_size:
+            to_numpy:
 
-        :param inputs: list of input data to encode
-        :param batch_size:
-        :param to_numpy:
-        :return: Numpy array or torch.Tensor of shape [input_size x embedding_size]
+        Returns:
+            Numpy array or torch.Tensor of shape (input_size, embedding_size)
         """
         self.eval()
         device = next(self.parameters(), torch.tensor(0)).device
@@ -185,7 +190,7 @@ class MetricModel(nn.Module):
             )
 
     @classmethod
-    def load(cls, input_path: str) -> "MetricModel":
+    def load(cls, input_path: str) -> MetricModel:
         with open(os.path.join(input_path, "config.json")) as f_in:
             config = json.load(f_in)
 
